@@ -1,6 +1,9 @@
 from yaml2obj.writer import YamlWriter
-
 from launchable_cli_args.error_counter import ErrorCounter
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from launchable_cli_args.cli_args import Commands
 
 
 class RecordSessionArgs:
@@ -14,7 +17,7 @@ class RecordSessionArgs:
     def write_to(self, writer: YamlWriter):
         return
 
-    def to_command(self):
+    def to_command(self) -> "Commands":
         return ("launchable", "record", "session", "--build", self.parent.eval_build_id())
 
     # returning an instance of this class(RecordSessionArgs) requires `from __future__ import annotations`
